@@ -193,9 +193,9 @@ C     mu
             else if(mu(i) .GT. 1-1e-5)then
                mu(i) = 1-1e-5
             endif
-         else if(family.EQ.3)then
-            mu(i) = exp(eta(i))
-         else if(family.EQ.4)then
+C         else if(family.EQ.3)then
+C            mu(i) = exp(eta(i))
+         else if(family.EQ.3 .OR. family.EQ.4)then
             if(eta(i) .LT. log(1e-5))then
                mu(i) = 1e-5
             else
@@ -285,8 +285,8 @@ C     dev
      +           (y(i)+theta)*dlog((y(i)+theta)/(mu(i) + theta)))) 
          endif
          if(cisnan(dev).NE.0) then
-             call intpr("dev is NA in Fortran src/deveval, check if
-     +        some columns of x have the same values", -1, 1, 1)
+             call intpr("dev is NA in Fortran src/deveval, check if some
+     +columns of x have the same values", -1, 1, 1)
             call intpr("i=", -1, i, 1)
             call dblepr("y(i)=", -1, y(i), 1)
             call dblepr("mu(i)=", -1, mu(i), 1)
